@@ -25,7 +25,7 @@ class CustomdataApi(BaseApi):
         # type: (string_types, dict) -> CustomData
         """Crop Filter Custom Data
 
-        :param filter_id: Id of the Crop configuration.
+        :param filter_id: Id of the Crop Filter.
         :type filter_id: string_types, required
         :return: Crop cofnig custom data
         :rtype: CustomData
